@@ -6,13 +6,13 @@ use Return::MultiLevel qw( with_return );
 use base 'Exporter';
 
 # ABSTRACT: Test that some code calls exec without terminating testing
-our $VERSION = '0.02_01'; # TRIAL VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 our @EXPORT = qw( exec_arrayref );
 
 our $exec_handler = sub {
-  CORE::exec(@_);
+  goto \&CORE::exec;
 };
 BEGIN {
   *CORE::GLOBAL::exec = sub { $exec_handler->(@_) };
@@ -44,7 +44,7 @@ Test::Exec - Test that some code calls exec without terminating testing
 
 =head1 VERSION
 
-version 0.02_01
+version 0.01
 
 =head1 SYNOPSIS
 
